<?php 

namespace PrestaShop\Module\PolarisPrestaConnector\Controller;

use PrestaShop\Module\PolarisPrestaConnector\Forms\GrilleType;
use PrestaShop\Module\PolarisPrestaConnector\Forms\InformationType;
use PrestaShop\Module\PolarisPrestaConnector\Forms\CatalogType;
use PrestaShop\Module\PolarisPrestaConnector\Forms\OrderType;
use Symfony\Component\HttpFoundation\Request;
use PrestaShop\Module\PolarisPrestaConnector\SyncConfiguration;
use PrestaShop\Module\PolarisPrestaConnector\Syncer;

class DocAdminController extends AdminController
{
    

    /**
     * Convertit du markdown en HTML, en mode simplifié (on a pas besoin de plus)
     */
    private function markdownToHtml(string $markdown): string
    {
        // Convertir les titres
        $markdown = preg_replace('/^#### (.*)$/m', '<h4>$1</h4>', $markdown);
        $markdown = preg_replace('/^### (.*)$/m', '<h3>$1</h3>', $markdown);
        $markdown = preg_replace('/^## (.*)$/m', '<h2>$1</h2>', $markdown);
        $markdown = preg_replace('/^# (.*)$/m', '<h1>$1</h1>', $markdown);

        // Convertir le gras et l'italique
        $markdown = preg_replace('/\*\*(.*?)\*\*/', '<strong>$1</strong>', $markdown); // **texte**
        $markdown = preg_replace('/\*(.*?)\*/', '<em>$1</em>', $markdown);           // *texte*
        // ```code``` => <pre></pre>
        $markdown = preg_replace('/```(.*?)```/s', '<pre>$1</pre>', $markdown);
        // ```code``` => <code></code>
        $markdown = preg_replace('/`(.*?)`/s', '<code>$1</code>', $markdown);

        // Convertir les listes
        $markdown = preg_replace('/^- (.*)$/m', '<li>$1</li>', $markdown);
        $markdown = preg_replace('/^\* (.*)$/m', '<li>$1</li>', $markdown);
        $markdown = preg_replace('/(<li>.*<\/li>)/s', '<ul>$1</ul>', $markdown);

        // Convertir les liens
        $markdown = preg_replace('/\[(.*?)\]\((.*?)\)/', '<a href="$2">$1</a>', $markdown); // [texte](url)

        // Convertir les sauts de ligne, que quand ils sont doublés
        $markdown = preg_replace('/\n\n/', '<br>', $markdown);        

        return $markdown;
    }      


    /** 
     * Rendu du Changelog
     */
    public function changelogDisplayAction() {
        $changelog = @file_get_contents($this->module->getLocalPath() . 'CHANGELOG.md');
        if (!$changelog)
            $changelog = "Le fichier CHANGELOG.md n'a pas pu être chargé.";

        // url de base 
        $base_url = \Context::getContext()->shop->getBaseURL() . 'modules/'. $this->module->name . '/';        

        return $this->render('@Modules/' . $this->module->name . '/views/templates/admin/showdoc.html.twig', $this->addDefaultVars([
            'url_userdoc' => $base_url.'docs/'.$this->module->BridgePrefix.'/CONFIGURE.pdf',
            'url_techdoc' => $base_url.'docs/'.$this->module->BridgePrefix.'/TECHNICALS.pdf',
            'changelog_html' => $this->markdownToHtml($changelog)
        ]));
    }
}