<?php

namespace PrestaShop\Module\PolarisPrestaConnector\Forms;

use PolarisPrestaConnector;
use PrestaShop\Module\PolarisPrestaConnector\SyncConfiguration;
use PrestaShopBundle\Form\Admin\Type\CustomContentType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\AbstractType;
use PrestaShopBundle\Form\Admin\Type\SwitchType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;

class InformationType extends AbstractType {


      /**
     * lien vers le module
     */
    protected PolarisPrestaConnector $module ;

    public function  __construct() {
        $this->module = \Module::getInstanceByName(strtolower('PolarisPrestaConnector'));
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
        ->add('synchro_active', SwitchType::class, [
            'label'=>'Synchronisation activée',
            'label_attr' => ['class' => 'label-mode'],
            // Indice pour l'utilisateur sur ce que fait le mode basique et le mode complet 
            'help' => 'Active ou désactive la synchronisation des données.',            
            'required' => false,
            'data' => $this->module->getCfg()->get(SyncConfiguration::CFG_ACTIVE ),
        ])

        ->add('cfg_mode', SwitchType::class, [
            'label'=>'Mode de synchronisation',
            'label_attr' => ['class' => 'label-mode'],
            'choices' => [
                'Mode basique' => true,
                'Mode complet' => false,
            ],
            // Indice pour l'utilisateur sur ce que fait le mode basique et le mode complet 
            'help' => 'Le mode basique synchronise les stocks, prix et promotions alors que le mode complet tient également les fiches produits à jour.',
            
            'required' => false,
            'data' => ($this->module->getCfg()->get(SyncConfiguration::CFG_WORKMODE) == 0) ? true : false,
        ])
        
        ->add('title_taskcron', CustomContentType::class, [
            'label' => false,
            'template' => '@Modules/prestaconnector/views/templates/admin/form_title.html.twig',
            'data' => [
                'hr' => true,
                'title' => 'Tâche de synchronisation',
                'help' => '<p>
                                Vous devez configurer une tâche cron qui appelle l\'URL suivante pour lancer la synchronisation automatiquement. 
                                Dans un cas standard, cet appel ne devrait pas être plus fréquent que toutes les 5 minutes.
                           </p>
                           <pre class="cron_url">'.\Context::getContext()->link->getBaseLink().'module/'.$this->module->name.'/cron?guard='.
                            urlencode($this->module->getCfg()->get(SyncConfiguration::CFG_GUARD_TOKEN)).'</pre>
                           ',
            ],
        ])

        ->add('guard_token', TextType::class, [
            'label'=>'Jeton d\'accès',
            // Indice pour l'utilisateur sur ce que fait le mode basique et le mode complet 
            'help' => 'Renseignez ici une chaîne de caractères aléatoires pour sécuriser l\'accès à la tâche de synchronisation.',
            'required' => false,
            'data' => $this->module->getCfg()->get(SyncConfiguration::CFG_GUARD_TOKEN),
        ])
        
        ->add('Enregistrer', SubmitType::class, [
            'attr' => ['class' => 'btn-form-valid btn-primary']
        ]);        
        
    }

}