<?php
namespace PrestaShop\Module\PolarisPrestaConnector;

/**
 * Objet de progression de synchronisation
 */
class SyncProgress
{
    private $data = [
        "step" => "Initialisation",
        "startTime" => null,
        "endTime" => null,
        "done" => 0,
        "stepDone" => 0,
        "stepNb" => 0
    ];

    /**
     * Si la configuration est définie, autosauvegarde
     */
    private SyncConfiguration|null $syncCfg = null;

    /**
     * Date de la dernière sauvegarde
     */
    private int $lastSave = 0;
    

    /**
     * Constructeur
     */
    public function __construct(SyncConfiguration|null $syncCfg = null, int $nbStep = 0)
    {
        $this->syncCfg = $syncCfg;
        $this->init($nbStep);
    }

    /**
     * Sérialisation de l'objet
     */
    public function toArray() : array
    {
        return $this->data;
    }

    /**
     * Désérialisation de l'objet
     */
    public static function fromArray(array $array)
    {
        $progress = new SyncProgress();
        if ($array)
        {
            foreach ($array as $key => $value)
                $progress->data[$key] = $value;
        }
        
        return $progress;
    }

    /**
     * Positionne le marqueur d'activité
     */
    public function setRunning(bool $running)
    {
        $this->data["running"] = $running;
    }

    /**
     * Décide quand sauver
     * 
     * @param bool $force Force la sauvegarde
     */
    protected function autosave($force = false)
    {
        if (!isset($this->syncCfg))
            return;
        // On sauve toutes les 5 secondes uniquement !
        if ($force || time() - $this->lastSave > 5)
        {
            $this->lastSave = time();
            $this->syncCfg->set(SyncConfiguration::CFG_SYNC_STATE, $this->toArray());
        }
    }

    /**
     * Démarre la progression
     */
    public function init(int $nbStep = 0)
    {
        $this->data["step"] = "Initialisation";
        $this->data["stepNb"] = $nbStep + 1;
        $this->data["startTime"] = time();        

        // sauvegarde ?
        $this->autosave(true);
    }

    /**
     * Ajout d'une étape
     */
    public function addStep(string $step)
    {
        $this->data["stepDone"]++;
        $this->data["step"] = $step;
        $this->data["stepNb"]++;

        // sauvegarde ?
        $this->autosave();
    }

    /**
     * Etape suivante
     */
    public function nextStep(string $step)
    {
        $this->data["stepDone"]++;
        $this->data["step"] = $step;

        // sauvegarde ?
        $this->autosave();
    }

    /**
     * Termine une synchronisation
     */
    public function end()
    {
        $this->data["step"] = "Fin";
        $this->data["endTime"] = time();
        // Force !
        $this->autosave(true);
    }
}